/* $Id: mosca_image.cpp,v 1.7 2013/01/28 12:46:40 cgarcia Exp $
 *
 * This file is part of the MOSCA library
 * Copyright (C) 2013 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: cgarcia $
 * $Date: 2013/01/28 12:46:40 $
 * $Revision: 1.7 $
 * $Name: fors-4_9_20 $
 */

#include <stdexcept>
#include "mosca_image.h"

mosca::image::image(cpl_size nx, cpl_size ny, cpl_type type, 
                    mosca::axis dispersion_axis)
{
    m_image = cpl_image_new(nx, ny, type);
    m_take_over = true;
    set_axis(dispersion_axis);
}
    
mosca::image::image()
{
    m_image = NULL;
    m_take_over = false;
}
    
mosca::image::image(cpl_image * image, bool take_over, 
                    mosca::axis dispersion_axis)
{
    m_image = image;
    m_take_over = take_over;
    set_axis(dispersion_axis);
}

mosca::image::~image()
{
    if(m_take_over)
        cpl_image_delete(m_image);
}

void mosca::image::set_axis(mosca::axis dispersion_axis)
{
    m_dispersion_axis = dispersion_axis;
    if(dispersion_axis == mosca::X_AXIS)
        m_spatial_axis    = mosca::Y_AXIS;
    else if(dispersion_axis == mosca::Y_AXIS)
        m_spatial_axis    = mosca::X_AXIS;
    else
        throw std::invalid_argument("Invalid dispersion axis. "
                                    "Use X_AXIS or Y_AXIS");
}

