/* $Id: mosca_image.h,v 1.5 2013/01/24 18:00:36 cgarcia Exp $
 *
 * This file is part of the MOSCA library
 * Copyright (C) 2013 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: cgarcia $
 * $Date: 2013/01/24 18:00:36 $
 * $Revision: 1.5 $
 * $Name: fors-4_9_20 $
 */

#ifndef MOSCA_IMAGE_H
#define MOSCA_IMAGE_H


#include "cpl_image.h"

namespace mosca
{

enum axis
{
    X_AXIS,
    Y_AXIS,
    DISPERSION_AXIS,
    SPATIAL_AXIS
};

/**
 * This class represents a 2d image. It uses cpl_image as an internal
 * image representation
 */
class image
{
public:
    image(cpl_size nx, cpl_size ny, cpl_type type = CPL_TYPE_DOUBLE,
          axis dispersion_axis = X_AXIS);
    
    image(cpl_image * image, bool take_over = false, 
          axis dispersion_axis = X_AXIS);
    
    image();
    
    virtual ~image();
    
    inline cpl_size size_x() const;

    inline cpl_size size_y() const;

    inline axis dispersion_axis() const;
    
    inline axis spatial_axis() const;

    template<typename T>
    inline T* get_data();

private:
    
    void set_axis(axis dispersion_axis);
    
    axis m_dispersion_axis;

    axis m_spatial_axis;

    bool m_take_over;
    
    cpl_image *  m_image;
};

}

#endif

#include "mosca_image.tcc"
